summaryrefslogtreecommitdiffstats
path: root/source/nsswitch/winbindd.h
diff options
context:
space:
mode:
Diffstat (limited to 'source/nsswitch/winbindd.h')
-rw-r--r--source/nsswitch/winbindd.h11
1 files changed, 1 insertions, 10 deletions
diff --git a/source/nsswitch/winbindd.h b/source/nsswitch/winbindd.h
index dd92ecefe61..4d35c27c213 100644
--- a/source/nsswitch/winbindd.h
+++ b/source/nsswitch/winbindd.h
@@ -29,9 +29,6 @@
#include "winbindd_nss.h"
-#undef DBGC_CLASS
-#define DBGC_CLASS DBGC_WINBIND
-
/* Client state structure */
struct winbindd_cli_state {
@@ -88,7 +85,7 @@ typedef struct {
struct winbindd_domain {
fstring name; /* Domain name */
- fstring alt_name; /* alt Domain name (if any) */
+ fstring full_name; /* full Domain name (realm) */
DOM_SID sid; /* SID for this domain */
/* Lookup methods for this domain (LDAP or RPC) */
@@ -170,15 +167,11 @@ struct winbindd_methods {
TALLOC_CTX *mem_ctx,
uint32 *num_domains,
char ***names,
- char ***alt_names,
DOM_SID **dom_sids);
/* find the domain sid */
NTSTATUS (*domain_sid)(struct winbindd_domain *domain,
DOM_SID *sid);
-
- /* setup the list of alternate names for the domain, if any */
- NTSTATUS (*alternate_name)(struct winbindd_domain *domain);
};
/* Used to glue a policy handle and cli_state together */
@@ -194,8 +187,6 @@ typedef struct {
#include "rpc_client.h"
#define WINBINDD_ESTABLISH_LOOP 30
-#define WINBINDD_RESCAN_FREQ 300
-
#define DOM_SEQUENCE_NONE ((uint32)-1)
/* SETENV */